from .models import ProxyModel
import os


def add_proxy(config: ProxyModel):
    os.environ['http_proxy'] = config.http_proxy
    os.environ['https_proxy'] = config.https_proxy
    os.environ['no_proxy'] = os.getenv('no_proxy') + ',' + config.no_proxy   


import os
from typing import Any, Dict
import requests
import json
import logging
import time
from .utils import load_config
from .proxy import add_proxy
from .models import ConfigModel, ProxyModel, TargetAPI, RequestResponse


class ApiClient:
    def __init__(
        self, 
        config_file_path: str,
        proxy: ProxyModel = None,
        **kwargs
    ) -> None:
        self.logger = kwargs.get('logger') or logging.getLogger()
        if proxy:
            add_proxy(proxy)
        self.config: ConfigModel = load_config(config_file_path)

    def _make_url_for_get_method(self, url: str, params: Dict) -> str:
        url += '?'
        for k, v in params.items():
            url += f'{str(k)}={str(v)}&'
        if url.endswith('&'):
            url = url[0:-1]
        return url

    def make_request(
        self, 
        target_name: str, 
        headers: Dict=None, 
        parameters: Dict=None
    ) -> RequestResponse:
        target: TargetAPI = self.config.config.get(target_name)
        if not target:
            return RequestResponse(message=f"not config for api endpoint {target_name}")
        
        _url = target.url
        _method = target.method
        _headers = target.header
        _parameters = target.parameters

        # update params
        if headers:
            _headers.update(headers)
        if parameters:
            _parameters.update(parameters)
        
        # handle url for method get
        if _method.lower() == 'get':
            _url = self._make_url_for_get_method(_url, _parameters)
            response = requests.get(_url, headers=_headers, verify=False)
        elif _method.lower() == 'post':
            response = requests.post(_url, headers=_headers, verify=False, data=json.dumps(_parameters))
        else:
            raise ValueError('just support get and post')

        try:
            response_data = json.loads(response.text)
        except:
            response_data = None

        if 200 <= response.status_code <= 300:
            return RequestResponse(success=True, data=response_data, code=response.status_code)
        else:
            return RequestResponse(success=False, data=response_data, code=response.status_code)





# -*- coding: utf-8 -*-
from .welcome import welcome
from .models import ProxyModel, RequestResponse
from .main import ApiClient

__version__ = "1.0.2"
__all__ = [
    "welcome",
    "ProxyModel",
    'RequestResponse',
    'ApiClient'
]



from pydantic import BaseModel
from typing import Any, Dict, List, Optional


class TargetAPI(BaseModel):
    url: str
    method: str
    header: Optional[Dict]
    parameters: Optional[Dict]
    save_response: bool = False


class ConfigModel(BaseModel):
    name: str
    description: str
    config: Dict[str, TargetAPI]


class ProxyModel(BaseModel):
    http_proxy: str
    https_proxy: str
    no_proxy: str


class RequestResponse(BaseModel):
    success: bool = False
    data: Any = None
    code: int = 0
    message: Optional[str]


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import io
import re
from setuptools import setup

PACKAGE_NAME = "ndd_rest_tools"

with io.open("%s/__init__.py" % PACKAGE_NAME, "rt", encoding="utf8") as f:
    version = re.search(r"__version__ = \"(.*?)\"", f.read()).group(1)

setup(version=version)
